====================
Clean Business Chart
====================


.. image:: https://img.shields.io/pypi/v/clean_business_chart.svg
        :target: https://pypi.python.org/pypi/clean_business_chart

.. image:: https://img.shields.io/travis/marcelw1323/clean_business_chart.svg
        :target: https://travis-ci.com/marcelw1323/clean_business_chart

.. image:: https://readthedocs.org/projects/clean-business-chart/badge/?version=latest
        :target: https://clean-business-chart.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Clean Business Chart is a Python package for IBCS-like charts based on matplotlib.


* Free software: MIT license
* Documentation: https://clean-business-chart.readthedocs.io.


Features
--------

* ColumnWithWaterfall, the first chart released with clean-business-chart!

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
